@@ -5,6 +5,7 @@ import pandas as pd
 model = UpliftRandomForestModel()
 data = pd.read_parquet("../train.parquet")
 x_names = list(data.columns[:-2])
+data.x3_informative = data.x3_informative.astype(int)
 
 model.fit(
     data,
@@ -14,15 +15,23 @@ model.fit(
     n_threads=8,
 )
 
-test = pd.read_parquet("../test.parquet")
 
-res = model.predict(data=test, n_threads=8)
+test = pd.read_parquet("../test.parquet")
+test.x3_informative = test.x3_informative.astype(int)
+res = model.predict(data=test[x_names].iloc[:4, :], n_threads=1)
 
 
 print(res[:10])
 
-# res = model.predict(data_file="../test.parquet", n_threads=8)
+row = list(test[x_names].iloc[5, :].values)
 
-# print(res[:10])
+print(row)
 
-# model.save("model.json")
+print(model.predict_row(row))
+
+model.save("model.json")
+
+newmodel = UpliftRandomForestModel()
+newmodel.load("model.json")
+
+print(newmodel.predict_row(row))
